@@ -1,9 +1,10 @@
-/* $Id: keyboard.h,v 1.9 1998/11/25 23:55:00 marcus Exp $
+/* $Id: keyboard.h,v 1.1.1.1 2001/05/12 23:00:11 cegger Exp $
 ******************************************************************************
 
    LibGII keyboard definitions
 
    Copyright (C) 1998 Andrew Apted	[andrew@ggi-project.org]
+   Copyright (C) 1999 Marcus Sundberg	[marcus@ggi-project.org]
 
    Permission is hereby granted, free of charge, to any person obtaining a
    copy of this software and associated documentation files (the "Software"),
@@ -39,23 +40,38 @@
 #define GII_KT_SPEC	0xE0
 #define GII_KT_FN	0xE1
 #define GII_KT_PAD	0xE2
-#define GII_KT_SHIFT	0xE3
-#define GII_KT_META	0xE4
-#define GII_KT_CONS	0xE5
+#define GII_KT_MOD	0xE3
+#define GII_KT_DEAD	0xE4
 
 /* modifiers */
 
-#define GII_KM_SHIFT	0
-#define GII_KM_CTRL	1
-#define GII_KM_ALT	2
-#define GII_KM_META	3
-#define GII_KM_SUPER	4
-#define GII_KM_HYPER	5
-#define GII_KM_TOP	6
-#define GII_KM_FRONT	7
+#define GII_KM_SHIFT	0x00
+#define GII_KM_CTRL	0x01
+#define GII_KM_ALT	0x02
+#define GII_KM_META	0x03
+#define GII_KM_SUPER	0x04
+#define GII_KM_HYPER	0x05
+#define GII_KM_ALTGR	0x06
+#define GII_KM_CAPS	0x07
+#define GII_KM_NUM	0x08
+#define GII_KM_SCROLL	0x09
 
-#define GII_KM_MASK	0x07
-#define GII_KM_RIGHT	0x10	/* additive */
+#define GII_KM_MASK	0x0f
+#define GII_KM_RIGHT	0x40	/* additive */
+#define GII_KM_LOCK	0x80	/*  - " -   (only used for labels) */
+
+/* Bits in the "modifiers" field */
+
+#define GII_MOD_SHIFT	(1 << GII_KM_SHIFT)
+#define GII_MOD_CTRL	(1 << GII_KM_CTRL)
+#define GII_MOD_ALT	(1 << GII_KM_ALT)
+#define GII_MOD_META	(1 << GII_KM_META)
+#define GII_MOD_SUPER	(1 << GII_KM_SUPER)
+#define GII_MOD_HYPER	(1 << GII_KM_HYPER)
+#define GII_MOD_ALTGR	(1 << GII_KM_ALTGR)
+#define GII_MOD_CAPS	(1 << GII_KM_CAPS)
+#define GII_MOD_NUM	(1 << GII_KM_NUM)
+#define GII_MOD_SCROLL	(1 << GII_KM_SCROLL)
 
 /* function keys */
 
@@ -131,27 +147,15 @@
 
 #define GIIK_Enter		GIIUC_Return
 #define GIIK_Delete		GIIUC_Delete
-#define GIIK_ShowRegs		GII_KEY(GII_KT_SPEC, 2)
-#define GIIK_ShowMem		GII_KEY(GII_KT_SPEC, 3)
-#define GIIK_ShowStat		GII_KEY(GII_KT_SPEC, 4)
+
 #define GIIK_Break		GII_KEY(GII_KT_SPEC, 5)
-#define GIIK_LastConsole	GII_KEY(GII_KT_SPEC, 6)
-#define GIIK_CapsLock		GII_KEY(GII_KT_SPEC, 7)
-#define GIIK_NumLock		GII_KEY(GII_KT_SPEC, 8)
-#define GIIK_ScrollLock		GII_KEY(GII_KT_SPEC, 9)
+
 #define GIIK_ScrollForw		GII_KEY(GII_KT_SPEC, 10)
 #define GIIK_ScrollBack		GII_KEY(GII_KT_SPEC, 11)
+
 #define GIIK_Boot		GII_KEY(GII_KT_SPEC, 12)
 #define GIIK_Compose		GII_KEY(GII_KT_SPEC, 14)
 #define GIIK_SAK		GII_KEY(GII_KT_SPEC, 15)
-#define GIIK_PrevConsole	GII_KEY(GII_KT_SPEC, 16)
-#define GIIK_DecrConsole	GIIK_PrevConsole
-#define GIIK_NextConsole	GII_KEY(GII_KT_SPEC, 17)
-#define GIIK_IncrConsole	GIIK_IncrConsole
-#define GIIK_SpawnConsole	GII_KEY(GII_KT_SPEC, 18)
-#define GIIK_TextScreen		GII_KEY(GII_KT_SPEC, 20)
-#define GIIK_GraphScreen	GII_KEY(GII_KT_SPEC, 21)
-#define GIIK_ToggleScreen	GII_KEY(GII_KT_SPEC, 22)
 
 #define GIIK_Undo		GII_KEY(GII_KT_SPEC, 23)
 #define GIIK_Redo		GII_KEY(GII_KT_SPEC, 24)
@@ -185,83 +189,88 @@
 
 /* keys on the numeric keypad */
 
-#define GIIK_P0			GII_KEY(GII_KT_PAD, 0)
-#define GIIK_P1			GII_KEY(GII_KT_PAD, 1)
-#define GIIK_P2			GII_KEY(GII_KT_PAD, 2)
-#define GIIK_P3			GII_KEY(GII_KT_PAD, 3)
-#define GIIK_P4			GII_KEY(GII_KT_PAD, 4)
-#define GIIK_P5			GII_KEY(GII_KT_PAD, 5)
-#define GIIK_P6			GII_KEY(GII_KT_PAD, 6)
-#define GIIK_P7			GII_KEY(GII_KT_PAD, 7)
-#define GIIK_P8			GII_KEY(GII_KT_PAD, 8)
-#define GIIK_P9			GII_KEY(GII_KT_PAD, 9)
-#define GIIK_PA			GII_KEY(GII_KT_PAD, 10)
-#define GIIK_PB			GII_KEY(GII_KT_PAD, 11)
-#define GIIK_PC			GII_KEY(GII_KT_PAD, 12)
-#define GIIK_PD			GII_KEY(GII_KT_PAD, 13)
-#define GIIK_PE			GII_KEY(GII_KT_PAD, 14)
-#define GIIK_PF			GII_KEY(GII_KT_PAD, 15)
+#define GIIK_P0			GII_KEY(GII_KT_PAD, '0')
+#define GIIK_P1			GII_KEY(GII_KT_PAD, '1')
+#define GIIK_P2			GII_KEY(GII_KT_PAD, '2')
+#define GIIK_P3			GII_KEY(GII_KT_PAD, '3')
+#define GIIK_P4			GII_KEY(GII_KT_PAD, '4')
+#define GIIK_P5			GII_KEY(GII_KT_PAD, '5')
+#define GIIK_P6			GII_KEY(GII_KT_PAD, '6')
+#define GIIK_P7			GII_KEY(GII_KT_PAD, '7')
+#define GIIK_P8			GII_KEY(GII_KT_PAD, '8')
+#define GIIK_P9			GII_KEY(GII_KT_PAD, '9')
+#define GIIK_PA			GII_KEY(GII_KT_PAD, 'A')
+#define GIIK_PB			GII_KEY(GII_KT_PAD, 'B')
+#define GIIK_PC			GII_KEY(GII_KT_PAD, 'C')
+#define GIIK_PD			GII_KEY(GII_KT_PAD, 'D')
+#define GIIK_PE			GII_KEY(GII_KT_PAD, 'E')
+#define GIIK_PF			GII_KEY(GII_KT_PAD, 'F')
 
-#define GIIK_PPlus		GII_KEY(GII_KT_PAD, 16)
-#define GIIK_PMinus		GII_KEY(GII_KT_PAD, 17)
-#define GIIK_PAsterisk		GII_KEY(GII_KT_PAD, 18)
+#define GIIK_PPlus		GII_KEY(GII_KT_PAD, '+')
+#define GIIK_PMinus		GII_KEY(GII_KT_PAD, '-')
+#define GIIK_PSlash		GII_KEY(GII_KT_PAD, '/')
+#define GIIK_PAsterisk		GII_KEY(GII_KT_PAD, '*')
 #define GIIK_PStar		GIIK_PAsterisk
-#define GIIK_PSlash		GII_KEY(GII_KT_PAD, 19)
-#define GIIK_PEnter		GII_KEY(GII_KT_PAD, 20)
-#define GIIK_PComma		GII_KEY(GII_KT_PAD, 21)
-#define GIIK_PDot		GII_KEY(GII_KT_PAD, 22)
-#define GIIK_PPlusMinus		GII_KEY(GII_KT_PAD, 23)
-#define GIIK_PParenLeft		GII_KEY(GII_KT_PAD, 24)
-#define GIIK_PParenRight	GII_KEY(GII_KT_PAD, 25)
-#define GIIK_PSpace		GII_KEY(GII_KT_PAD, 26)
-#define GIIK_PTab		GII_KEY(GII_KT_PAD, 27)
-#define GIIK_PBegin		GII_KEY(GII_KT_PAD, 28)
-#define GIIK_PInsert		GII_KEY(GII_KT_PAD, 29)
-#define GIIK_PEqual		GII_KEY(GII_KT_PAD, 30)
-#define GIIK_PSeparator		GII_KEY(GII_KT_PAD, 31)
-#define GIIK_PNumber		GII_KEY(GII_KT_PAD, 32)
-#define GIIK_PHash		GIIK_PNumber
+#define GIIK_PEqual		GII_KEY(GII_KT_PAD, '=')
+#define GIIK_PSeparator		GII_KEY(GII_KT_PAD, ',')
+#define GIIK_PDecimal		GII_KEY(GII_KT_PAD, '.')
+#define GIIK_PParenLeft		GII_KEY(GII_KT_PAD, '(')
+#define GIIK_PParenRight	GII_KEY(GII_KT_PAD, ')')
+#define GIIK_PSpace		GII_KEY(GII_KT_PAD, ' ')
+#define GIIK_PEnter		GII_KEY(GII_KT_PAD, '\r')
+#define GIIK_PTab		GII_KEY(GII_KT_PAD, '\t')
 
-#define GIIK_PF0		GII_KEY(GII_KT_PAD, 40)
-#define GIIK_PF1		GII_KEY(GII_KT_PAD, 41)
-#define GIIK_PF2		GII_KEY(GII_KT_PAD, 42)
-#define GIIK_PF3		GII_KEY(GII_KT_PAD, 43)
-#define GIIK_PF4		GII_KEY(GII_KT_PAD, 44)
-#define GIIK_PF5		GII_KEY(GII_KT_PAD, 45)
-#define GIIK_PF6		GII_KEY(GII_KT_PAD, 46)
-#define GIIK_PF7		GII_KEY(GII_KT_PAD, 47)
-#define GIIK_PF8		GII_KEY(GII_KT_PAD, 48)
-#define GIIK_PF9		GII_KEY(GII_KT_PAD, 49)
+#define GIIK_PPlusMinus		GII_KEY(GII_KT_PAD, 0x80)
+#define GIIK_PBegin		GII_KEY(GII_KT_PAD, 0x81)
+
+#define GIIK_PF1		GII_KEY(GII_KT_PAD, 0x91)
+#define GIIK_PF2		GII_KEY(GII_KT_PAD, 0x92)
+#define GIIK_PF3		GII_KEY(GII_KT_PAD, 0x93)
+#define GIIK_PF4		GII_KEY(GII_KT_PAD, 0x94)
+#define GIIK_PF5		GII_KEY(GII_KT_PAD, 0x95)
+#define GIIK_PF6		GII_KEY(GII_KT_PAD, 0x96)
+#define GIIK_PF7		GII_KEY(GII_KT_PAD, 0x97)
+#define GIIK_PF8		GII_KEY(GII_KT_PAD, 0x98)
+#define GIIK_PF9		GII_KEY(GII_KT_PAD, 0x99)
 
 /* modifier keys */
 
-#define GIIK_Shift		GII_KEY(GII_KT_SHIFT, GII_KM_SHIFT)
-#define GIIK_Ctrl		GII_KEY(GII_KT_SHIFT, GII_KM_CTRL)
-#define GIIK_Alt		GII_KEY(GII_KT_SHIFT, GII_KM_ALT)
-#define GIIK_Meta		GII_KEY(GII_KT_SHIFT, GII_KM_META)
-#define GIIK_Super		GII_KEY(GII_KT_SHIFT, GII_KM_SUPER)
-#define GIIK_Hyper		GII_KEY(GII_KT_SHIFT, GII_KM_HYPER)
-#define GIIK_Top		GII_KEY(GII_KT_SHIFT, GII_KM_TOP)
-#define GIIK_Front		GII_KEY(GII_KT_SHIFT, GII_KM_FRONT)
+#define GIIK_Shift		GII_KEY(GII_KT_MOD, GII_KM_SHIFT)
+#define GIIK_Ctrl		GII_KEY(GII_KT_MOD, GII_KM_CTRL)
+#define GIIK_Alt		GII_KEY(GII_KT_MOD, GII_KM_ALT)
+#define GIIK_Meta		GII_KEY(GII_KT_MOD, GII_KM_META)
+#define GIIK_Super		GII_KEY(GII_KT_MOD, GII_KM_SUPER)
+#define GIIK_Hyper		GII_KEY(GII_KT_MOD, GII_KM_HYPER)
+#define GIIK_AltGr		GII_KEY(GII_KT_MOD, GII_KM_ALTGR)
+#define GIIK_Caps		GII_KEY(GII_KT_MOD, GII_KM_CAPS)
+#define GIIK_Num		GII_KEY(GII_KT_MOD, GII_KM_NUM)
+#define GIIK_Scroll		GII_KEY(GII_KT_MOD, GII_KM_SCROLL)
 
 /* modifier _labels_ */
 
-#define GIIK_ShiftL		(GIIK_Shift | 0)
-#define GIIK_ShiftR		(GIIK_Shift | GII_KM_RIGHT)
-#define GIIK_CtrlL		(GIIK_Ctrl  | 0)
-#define GIIK_CtrlR		(GIIK_Ctrl  | GII_KM_RIGHT)
-#define GIIK_AltL		(GIIK_Alt   | 0)
-#define GIIK_AltR		(GIIK_Alt   | GII_KM_RIGHT)
-#define GIIK_MetaL		(GIIK_Meta  | 0)
-#define GIIK_MetaR		(GIIK_Meta  | GII_KM_RIGHT)
-#define GIIK_SuperL		(GIIK_Super | 0)
-#define GIIK_SuperR		(GIIK_Super | GII_KM_RIGHT)
-#define GIIK_HyperL		(GIIK_Hyper | 0)
-#define GIIK_HyperR		(GIIK_Hyper | GII_KM_RIGHT)
-#define GIIK_TopL		(GIIK_Top   | 0)
-#define GIIK_TopR		(GIIK_Top   | GII_KM_RIGHT)
-#define GIIK_FrontL		(GIIK_Front | 0)
-#define GIIK_FrontR		(GIIK_Front | GII_KM_RIGHT)
+#define GIIK_ShiftL		(GIIK_Shift  | 0)
+#define GIIK_ShiftR		(GIIK_Shift  | GII_KM_RIGHT)
+#define GIIK_CtrlL		(GIIK_Ctrl   | 0)
+#define GIIK_CtrlR		(GIIK_Ctrl   | GII_KM_RIGHT)
+#define GIIK_AltL		(GIIK_Alt    | 0)
+#define GIIK_AltR		(GIIK_Alt    | GII_KM_RIGHT)
+#define GIIK_MetaL		(GIIK_Meta   | 0)
+#define GIIK_MetaR		(GIIK_Meta   | GII_KM_RIGHT)
+#define GIIK_SuperL		(GIIK_Super  | 0)
+#define GIIK_SuperR		(GIIK_Super  | GII_KM_RIGHT)
+#define GIIK_HyperL		(GIIK_Hyper  | 0)
+#define GIIK_HyperR		(GIIK_Hyper  | GII_KM_RIGHT)
+
+#define GIIK_ShiftLock		(GIIK_Shift  | GII_KM_LOCK)
+#define GIIK_CtrlLock		(GIIK_Ctrl   | GII_KM_LOCK)
+#define GIIK_AltLock		(GIIK_Alt    | GII_KM_LOCK)
+#define GIIK_MetaLock		(GIIK_Meta   | GII_KM_LOCK)
+#define GIIK_SuperLock		(GIIK_Super  | GII_KM_LOCK)
+#define GIIK_HyperLock		(GIIK_Hyper  | GII_KM_LOCK)
+#define GIIK_AltGrLock		(GIIK_AltGr  | GII_KM_LOCK)
+#define GIIK_CapsLock		(GIIK_Caps   | GII_KM_LOCK)
+#define GIIK_NumLock		(GIIK_Num    | GII_KM_LOCK)
+#define GIIK_ScrollLock		(GIIK_Scroll | GII_KM_LOCK)
 
 /* miscellaneous */
 
@@ -493,4 +502,24 @@
 #define GIIUC_ydiaeresis	0xff
 #define GIIUC_yumlaut		GIIUC_ydiaeresis
 
+/* Dead keys */
+#define GIIK_DeadRing			GII_KEY(GII_KT_DEAD, 0x00)
+#define GIIK_DeadCaron			GII_KEY(GII_KT_DEAD, 0x01)
+#define GIIK_DeadOgonek			GII_KEY(GII_KT_DEAD, 0x02)
+#define GIIK_DeadIota			GII_KEY(GII_KT_DEAD, 0x03)
+#define GIIK_DeadDoubleAcute		GII_KEY(GII_KT_DEAD, 0x04)
+#define GIIK_DeadBreve			GII_KEY(GII_KT_DEAD, 0x05)
+#define GIIK_DeadAboveDot		GII_KEY(GII_KT_DEAD, 0x06)
+#define GIIK_DeadBelowDot		GII_KEY(GII_KT_DEAD, 0x07)
+#define GIIK_DeadVoicedSound		GII_KEY(GII_KT_DEAD, 0x08)
+#define GIIK_DeadSemiVoicedSound	GII_KEY(GII_KT_DEAD, 0x09)
+
+#define GIIK_DeadAcute			GII_KEY(GII_KT_DEAD, GIIUC_Acute)
+#define GIIK_DeadCedilla		GII_KEY(GII_KT_DEAD, GIIUC_Cedilla)
+#define GIIK_DeadCircumflex		GII_KEY(GII_KT_DEAD, GIIUC_Circumflex)
+#define GIIK_DeadDiaeresis		GII_KEY(GII_KT_DEAD, GIIUC_Diaeresis)
+#define GIIK_DeadGrave			GII_KEY(GII_KT_DEAD, GIIUC_Grave)
+#define GIIK_DeadTilde			GII_KEY(GII_KT_DEAD, GIIUC_Tilde)
+#define GIIK_DeadMacron			GII_KEY(GII_KT_DEAD, GIIUC_Macron)
+
 #endif /* _GII_KEYBOARD_H */
